@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Rerrah
+ * Copyright (C) 2018-2022 Rerrah
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -44,6 +44,7 @@ const QString APPLICATION = "BambooTracker";
 
 const std::unordered_map<Configuration::ShortcutAction, QString> SHORTCUTS_NAME_MAP = {
 	{ Configuration::ShortcutAction::KeyOff, "keyOff" },
+	{ Configuration::ShortcutAction::KeyCut, "keyCut" },
 	{ Configuration::ShortcutAction::OctaveUp, "octaveUp" },
 	{ Configuration::ShortcutAction::OctaveDown, "octaveDown" },
 	{ Configuration::ShortcutAction::EchoBuffer, "echoBuffer" },
@@ -256,6 +257,8 @@ bool saveConfiguration(std::weak_ptr<Configuration> config)
 		settings.setValue("emulator",		configLocked->getEmulator());
 		settings.setValue("sampleRate",   static_cast<int>(configLocked->getSampleRate()));
 		settings.setValue("bufferLength", static_cast<int>(configLocked->getBufferLength()));
+		settings.setValue("resamplerType", static_cast<int>(configLocked->getResamplerType()));
+		settings.setValue("immediateWriteModeEnabled", configLocked->getImmediateWriteModeEnabled());
 		settings.endGroup();
 
 		// Midi //
@@ -289,13 +292,9 @@ bool saveConfiguration(std::weak_ptr<Configuration> config)
 
 		settings.beginGroup("Appearance");
 		settings.setValue("patternEditorHeaderFont", QString::fromStdString(configLocked->getPatternEditorHeaderFont()));
-		settings.setValue("patternEditorHeaderFontSize", configLocked->getPatternEditorHeaderFontSize());
 		settings.setValue("patternEditorRowsFont", QString::fromStdString(configLocked->getPatternEditorRowsFont()));
-		settings.setValue("patternEditorRowsFontSize", configLocked->getPatternEditorRowsFontSize());
 		settings.setValue("orderListHeaderFont", QString::fromStdString(configLocked->getOrderListHeaderFont()));
-		settings.setValue("orderListHeaderFontSize", configLocked->getOrderListHeaderFontSize());
 		settings.setValue("orderListRowsFont", QString::fromStdString(configLocked->getOrderListRowsFont()));
-		settings.setValue("orderListRowsFontSize", configLocked->getOrderListRowsFontSize());
 		settings.endGroup();
 
 		return true;
@@ -445,6 +444,9 @@ bool loadConfiguration(std::weak_ptr<Configuration> config)
 		QVariant bufferLengthWorkaround;
 		bufferLengthWorkaround.setValue(configLocked->getBufferLength());
 		configLocked->setBufferLength(static_cast<size_t>(settings.value("bufferLength", bufferLengthWorkaround).toInt()));
+		configLocked->setResamplerType(static_cast<chip::ResamplerType>(
+										   settings.value("resamplerType", static_cast<int>(configLocked->getResamplerType())).toInt()));
+		configLocked->setImmediateWriteModeEnabled(settings.value("immediateWriteModeEnabled", configLocked->getImmediateWriteModeEnabled()).toBool());
 		settings.endGroup();
 
 		// Midi //
@@ -482,13 +484,9 @@ bool loadConfiguration(std::weak_ptr<Configuration> config)
 		// Appearance
 		settings.beginGroup("Appearance");
 		configLocked->setPatternEditorHeaderFont(settings.value("patternEditorHeaderFont", QString::fromStdString(configLocked->getPatternEditorHeaderFont())).toString().toStdString());
-		configLocked->setPatternEditorHeaderFontSize(settings.value("patternEditorHeaderFontSize", configLocked->getPatternEditorHeaderFontSize()).toInt());
 		configLocked->setPatternEditorRowsFont(settings.value("patternEditorRowsFont", QString::fromStdString(configLocked->getPatternEditorRowsFont())).toString().toStdString());
-		configLocked->setPatternEditorRowsFontSize(settings.value("patternEditorRowsFontSize", configLocked->getPatternEditorRowsFontSize()).toInt());
 		configLocked->setOrderListHeaderFont(settings.value("orderListHeaderFont", QString::fromStdString(configLocked->getOrderListHeaderFont())).toString().toStdString());
-		configLocked->setOrderListHeaderFontSize(settings.value("orderListHeaderFontSize", configLocked->getOrderListHeaderFontSize()).toInt());
 		configLocked->setOrderListRowsFont(settings.value("orderListRowsFont", QString::fromStdString(configLocked->getOrderListRowsFont())).toString().toStdString());
-		configLocked->setOrderListRowsFontSize(settings.value("orderListRowsFontSize", configLocked->getOrderListRowsFontSize()).toInt());
 		settings.endGroup();
 
 		return true;
