@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Rerrah
+ * Copyright (C) 2020-2023 Rerrah
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -985,6 +985,18 @@ AbstractInstrument* BtiIO::load(const BinaryContainer& ctr, const std::string& f
 							break;
 						case 0x01:	// Fixed
 							instManLocked->setArpeggioFMType(idx, SequenceType::FixedSequence);
+							if (fileVersion < Version::toBCD(1, 5, 1)) {
+								// Add infinity loop to the last data, to keep compatibility
+								auto loopRt = instManLocked->getArpeggioFMLoopRoot(idx).getAllLoops();
+								if (std::none_of(loopRt.begin(), loopRt.end(), [](InstrumentSequenceLoop& loop) { return loop.isInfinite(); })) {
+									auto seq = instManLocked->getArpeggioFMSequence(idx);
+									if (!seq.empty()) {
+										size_t pos = seq.size();
+										instManLocked->addArpeggioFMSequenceData(idx, seq.back().data);
+										instManLocked->addArpeggioFMLoop(idx, InstrumentSequenceLoop(pos, pos, InstrumentSequenceLoop::INFINITE_LOOP));
+									}
+								}
+							}
 							break;
 						case 0x02:	// Relative
 							instManLocked->setArpeggioFMType(idx, SequenceType::RelativeSequence);
@@ -1429,6 +1441,18 @@ AbstractInstrument* BtiIO::load(const BinaryContainer& ctr, const std::string& f
 							break;
 						case 0x01:	// Fixed
 							instManLocked->setArpeggioSSGType(idx, SequenceType::FixedSequence);
+							if (fileVersion < Version::toBCD(1, 5, 1)) {
+								// Add infinity loop to the last data, to keep compatibility
+								auto loopRt = instManLocked->getArpeggioSSGLoopRoot(idx).getAllLoops();
+								if (std::none_of(loopRt.begin(), loopRt.end(), [](InstrumentSequenceLoop& loop) { return loop.isInfinite(); })) {
+									auto seq = instManLocked->getArpeggioSSGSequence(idx);
+									if (!seq.empty()) {
+										size_t pos = seq.size();
+										instManLocked->addArpeggioSSGSequenceData(idx, seq.back().data);
+										instManLocked->addArpeggioSSGLoop(idx, InstrumentSequenceLoop(pos, pos, InstrumentSequenceLoop::INFINITE_LOOP));
+									}
+								}
+							}
 							break;
 						case 0x02:	// Relative
 							instManLocked->setArpeggioSSGType(idx, SequenceType::RelativeSequence);
@@ -1545,8 +1569,18 @@ AbstractInstrument* BtiIO::load(const BinaryContainer& ctr, const std::string& f
 					uint32_t len = ctr.readUint32(csr);
 					csr += 4;
 					std::vector<uint8_t> samples = ctr.getSubcontainer(csr, len).toVector();
-					/* csr += len; */
-					instManLocked->storeSampleADPCMRawSample(idx, std::move(samples));
+					 csr += len;
+					instManLocked->storeSampleADPCMRawSample(idx, samples);
+					if (fileVersion >= Version::toBCD(1, 5, 1)) {
+						uint16_t repeatBegin = ctr.readUint16(csr);
+						csr += 2;
+						uint16_t repeatEnd = ctr.readUint16(csr);
+						csr += 2;
+						instManLocked->setSampleADPCMRepeatrange(idx, SampleRepeatRange(repeatBegin, repeatEnd));
+					}
+					else {
+						instManLocked->setSampleADPCMRepeatrange(idx, SampleRepeatRange(0, (samples.size() - 1) >> 5));
+					}
 
 					instPropCsr += ofs;
 					break;
@@ -1678,6 +1712,18 @@ AbstractInstrument* BtiIO::load(const BinaryContainer& ctr, const std::string& f
 						break;
 					case 0x01:	// Fixed
 						instManLocked->setArpeggioADPCMType(idx, SequenceType::FixedSequence);
+						if (fileVersion < Version::toBCD(1, 5, 1)) {
+							// Add infinity loop to the last data, to keep compatibility
+							auto loopRt = instManLocked->getArpeggioADPCMLoopRoot(idx).getAllLoops();
+							if (std::none_of(loopRt.begin(), loopRt.end(), [](InstrumentSequenceLoop& loop) { return loop.isInfinite(); })) {
+								auto seq = instManLocked->getArpeggioADPCMSequence(idx);
+								if (!seq.empty()) {
+									size_t pos = seq.size();
+									instManLocked->addArpeggioADPCMSequenceData(idx, seq.back().data);
+									instManLocked->addArpeggioADPCMLoop(idx, InstrumentSequenceLoop(pos, pos, InstrumentSequenceLoop::INFINITE_LOOP));
+								}
+							}
+						}
 						break;
 					case 0x02:	// Relative
 						instManLocked->setArpeggioADPCMType(idx, SequenceType::RelativeSequence);
@@ -2420,6 +2466,9 @@ void BtiIO::save(BinaryContainer& ctr,
 			std::vector<uint8_t> samples = instManLocked->getSampleADPCMRawSample(sampNum);
 			ctr.appendUint32(samples.size());
 			ctr.appendVector(std::move(samples));
+			SampleRepeatRange range = instMan.lock()->getSampleADPCMRepeatRange(sampNum);
+			ctr.appendUint16(range.first());
+			ctr.appendUint16(range.last());
 			ctr.writeUint32(ofs, ctr.size() - ofs);
 		}
 
@@ -2613,6 +2662,9 @@ void BtiIO::save(BinaryContainer& ctr,
 					std::vector<uint8_t> samples = instManLocked->getSampleADPCMRawSample(samp);
 					ctr.appendUint32(samples.size());
 					ctr.appendVector(std::move(samples));
+					SampleRepeatRange range = instMan.lock()->getSampleADPCMRepeatRange(samp);
+					ctr.appendUint16(range.first());
+					ctr.appendUint16(range.last());
 					ctr.writeUint32(ofs, ctr.size() - ofs);
 				}
 			}
